abacusai.organization_external_application_settings — AbacusAI documentation

# abacusai.organization_external_application_settings

## Classes

`OrganizationExternalApplicationSettings` | The External Application Settings for an Organization.

## Module Contents

class abacusai.organization_external_application_settings.OrganizationExternalApplicationSettings(client, logo=None, theme=None, managedUserService=None, passwordsDisabled=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The External Application Settings for an Organization.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - logo (str) – The logo.

    - theme (dict) – The theme used for External Applications in this org.

    - managedUserService (str) – The external service that is managing the user accounts.

    - passwordsDisabled (bool) – Whether or not passwords are disabled for this organization’s domain.

  logo
  theme
  managed_user_service
  passwords_disabled
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict